@@ -1,10 +1,10 @@
 package Games::Solitaire::Verify::FromOtherSolversBase;
-$Games::Solitaire::Verify::FromOtherSolversBase::VERSION = '0.2401';
+$Games::Solitaire::Verify::FromOtherSolversBase::VERSION = '0.2402';
 use strict;
 use warnings;
 use autodie;
 
-use List::MoreUtils qw(firstidx);
+use List::Util qw(first);
 use Path::Tiny qw/ path /;
 
 use parent 'Games::Solitaire::Verify::Base';
@@ -193,7 +193,7 @@ sub _find_col_card
 {
     my ( $self, $card_s ) = @_;
 
-    return firstidx
+    return first
     {
         my $col = $self->_st->get_column($_);
         ( $col->len == 0 ) ? 0 : $col->top->fast_s eq $card_s
@@ -205,7 +205,7 @@ sub _find_empty_col
 {
     my ($self) = @_;
 
-    return firstidx
+    return first
     {
         $self->_st->get_column($_)->len == 0
     }
@@ -215,7 +215,7 @@ sub _find_empty_col
 sub _find_fc_card
 {
     my ( $self, $card_s ) = @_;
-    my $dest_fc_idx = firstidx
+    return first
     {
         my $card = $self->_st->get_freecell($_);
         defined($card) ? ( $card->fast_s eq $card_s ) : 0;
@@ -229,10 +229,10 @@ sub _find_card_src_string
 
     my $src_col_idx = $self->_find_col_card($src_card_s);
 
-    if ( $src_col_idx < 0 )
+    if ( not defined $src_col_idx )
     {
         my $src_fc_idx = $self->_find_fc_card($src_card_s);
-        if ( $src_fc_idx < 0 )
+        if ( not defined($src_fc_idx) )
         {
             die "Cannot find card <$src_card_s>.";
         }
@@ -270,7 +270,7 @@ class for converters.
 
 =head1 VERSION
 
-version 0.2401
+version 0.2402
 
 =head1 SYNOPSIS
 
@@ -378,7 +378,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Shlomi Fish.
+This software is Copyright (c) 2008 by Shlomi Fish.
 
 This is free software, licensed under:
 
